module Top {
    module A__2 {
        export function b__3() {}
    }
    A__2.b();
}
